From 526a440203d1ff96640c6163291e57e10c8e4f9b Mon Sep 17 00:00:00 2001
From: Maksym H <1177472+mordamax@users.noreply.github.com>
Date: Fri, 6 Dec 2024 13:34:08 +0100
Subject: [PATCH] Update weights for westend pallet balances (#6777)

Co-authored-by: command-bot <>
---
 .../westend/src/weights/pallet_balances.rs    | 52 +++++++++----------
 1 file changed, 26 insertions(+), 26 deletions(-)

diff --git a/polkadot/runtime/westend/src/weights/pallet_balances.rs b/polkadot/runtime/westend/src/weights/pallet_balances.rs
index 5e91f31920c..b303a1a2176 100644
--- a/polkadot/runtime/westend/src/weights/pallet_balances.rs
+++ b/polkadot/runtime/westend/src/weights/pallet_balances.rs
@@ -17,9 +17,9 @@
 //! Autogenerated weights for `pallet_balances`
 //!
 //! THIS FILE WAS AUTO-GENERATED USING THE SUBSTRATE BENCHMARK CLI VERSION 32.0.0
-//! DATE: 2024-05-06, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
+//! DATE: 2024-12-05, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
 //! WORST CASE MAP SIZE: `1000000`
-//! HOSTNAME: `runner-unxyhko3-project-674-concurrent-0`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
+//! HOSTNAME: `runner-wiukf8gn-project-674-concurrent-0`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
 //! WASM-EXECUTION: `Compiled`, CHAIN: `Some("westend-dev")`, DB CACHE: 1024
 
 // Executed Command:
@@ -54,8 +54,8 @@ impl<T: frame_system::Config> pallet_balances::WeightInfo for WeightInfo<T> {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `3593`
-		// Minimum execution time: 43_248_000 picoseconds.
-		Weight::from_parts(43_872_000, 0)
+		// Minimum execution time: 50_394_000 picoseconds.
+		Weight::from_parts(51_666_000, 0)
 			.saturating_add(Weight::from_parts(0, 3593))
 			.saturating_add(T::DbWeight::get().reads(1))
 			.saturating_add(T::DbWeight::get().writes(1))
@@ -66,8 +66,8 @@ impl<T: frame_system::Config> pallet_balances::WeightInfo for WeightInfo<T> {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `3593`
-		// Minimum execution time: 33_990_000 picoseconds.
-		Weight::from_parts(34_693_000, 0)
+		// Minimum execution time: 40_307_000 picoseconds.
+		Weight::from_parts(41_722_000, 0)
 			.saturating_add(Weight::from_parts(0, 3593))
 			.saturating_add(T::DbWeight::get().reads(1))
 			.saturating_add(T::DbWeight::get().writes(1))
@@ -78,8 +78,8 @@ impl<T: frame_system::Config> pallet_balances::WeightInfo for WeightInfo<T> {
 		// Proof Size summary in bytes:
 		//  Measured:  `174`
 		//  Estimated: `3593`
-		// Minimum execution time: 12_681_000 picoseconds.
-		Weight::from_parts(13_183_000, 0)
+		// Minimum execution time: 19_110_000 picoseconds.
+		Weight::from_parts(19_623_000, 0)
 			.saturating_add(Weight::from_parts(0, 3593))
 			.saturating_add(T::DbWeight::get().reads(1))
 			.saturating_add(T::DbWeight::get().writes(1))
@@ -90,8 +90,8 @@ impl<T: frame_system::Config> pallet_balances::WeightInfo for WeightInfo<T> {
 		// Proof Size summary in bytes:
 		//  Measured:  `174`
 		//  Estimated: `3593`
-		// Minimum execution time: 17_474_000 picoseconds.
-		Weight::from_parts(18_063_000, 0)
+		// Minimum execution time: 26_837_000 picoseconds.
+		Weight::from_parts(27_672_000, 0)
 			.saturating_add(Weight::from_parts(0, 3593))
 			.saturating_add(T::DbWeight::get().reads(1))
 			.saturating_add(T::DbWeight::get().writes(1))
@@ -102,8 +102,8 @@ impl<T: frame_system::Config> pallet_balances::WeightInfo for WeightInfo<T> {
 		// Proof Size summary in bytes:
 		//  Measured:  `103`
 		//  Estimated: `6196`
-		// Minimum execution time: 45_699_000 picoseconds.
-		Weight::from_parts(46_099_000, 0)
+		// Minimum execution time: 53_032_000 picoseconds.
+		Weight::from_parts(54_040_000, 0)
 			.saturating_add(Weight::from_parts(0, 6196))
 			.saturating_add(T::DbWeight::get().reads(2))
 			.saturating_add(T::DbWeight::get().writes(2))
@@ -114,8 +114,8 @@ impl<T: frame_system::Config> pallet_balances::WeightInfo for WeightInfo<T> {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `3593`
-		// Minimum execution time: 42_453_000 picoseconds.
-		Weight::from_parts(43_133_000, 0)
+		// Minimum execution time: 49_429_000 picoseconds.
+		Weight::from_parts(50_020_000, 0)
 			.saturating_add(Weight::from_parts(0, 3593))
 			.saturating_add(T::DbWeight::get().reads(1))
 			.saturating_add(T::DbWeight::get().writes(1))
@@ -126,8 +126,8 @@ impl<T: frame_system::Config> pallet_balances::WeightInfo for WeightInfo<T> {
 		// Proof Size summary in bytes:
 		//  Measured:  `174`
 		//  Estimated: `3593`
-		// Minimum execution time: 15_066_000 picoseconds.
-		Weight::from_parts(15_605_000, 0)
+		// Minimum execution time: 22_114_000 picoseconds.
+		Weight::from_parts(22_526_000, 0)
 			.saturating_add(Weight::from_parts(0, 3593))
 			.saturating_add(T::DbWeight::get().reads(1))
 			.saturating_add(T::DbWeight::get().writes(1))
@@ -139,11 +139,11 @@ impl<T: frame_system::Config> pallet_balances::WeightInfo for WeightInfo<T> {
 		// Proof Size summary in bytes:
 		//  Measured:  `0 + u * (136 ±0)`
 		//  Estimated: `990 + u * (2603 ±0)`
-		// Minimum execution time: 14_180_000 picoseconds.
-		Weight::from_parts(14_598_000, 0)
+		// Minimum execution time: 17_550_000 picoseconds.
+		Weight::from_parts(17_860_000, 0)
 			.saturating_add(Weight::from_parts(0, 990))
-			// Standard Error: 13_221
-			.saturating_add(Weight::from_parts(13_422_901, 0).saturating_mul(u.into()))
+			// Standard Error: 11_891
+			.saturating_add(Weight::from_parts(15_027_705, 0).saturating_mul(u.into()))
 			.saturating_add(T::DbWeight::get().reads((1_u64).saturating_mul(u.into())))
 			.saturating_add(T::DbWeight::get().writes((1_u64).saturating_mul(u.into())))
 			.saturating_add(Weight::from_parts(0, 2603).saturating_mul(u.into()))
@@ -152,24 +152,24 @@ impl<T: frame_system::Config> pallet_balances::WeightInfo for WeightInfo<T> {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 5_130_000 picoseconds.
-		Weight::from_parts(5_257_000, 0)
+		// Minimum execution time: 6_605_000 picoseconds.
+		Weight::from_parts(6_922_000, 0)
 			.saturating_add(Weight::from_parts(0, 0))
 	}
 	fn burn_allow_death() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 27_328_000 picoseconds.
-		Weight::from_parts(27_785_000, 0)
+		// Minimum execution time: 31_182_000 picoseconds.
+		Weight::from_parts(32_104_000, 0)
 			.saturating_add(Weight::from_parts(0, 0))
 	}
 	fn burn_keep_alive() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 17_797_000 picoseconds.
-		Weight::from_parts(18_103_000, 0)
+		// Minimum execution time: 21_105_000 picoseconds.
+		Weight::from_parts(21_533_000, 0)
 			.saturating_add(Weight::from_parts(0, 0))
 	}
 }
-- 
GitLab